@@ -1,25 +1,30 @@
-import base64
+
 from Crypto.Cipher import AES
-from Crypto import  Random
-import io
+from Crypto import Random
+
 """
 AES对称加密算法
 """
+
+
 def pad(s):
     return s + b"\0" * (AES.block_size - len(s) % AES.block_size)
 
-def encrypt(message, key, key_size=256):
+
+def encrypt(message, key):
     message = pad(message)
     iv = Random.new().read(AES.block_size)
     cipher = AES.new(key, AES.MODE_CBC, iv)
     return iv + cipher.encrypt(message)
 
+
 def decrypt(ciphertext, key):
     iv = ciphertext[:AES.block_size]
     cipher = AES.new(key, AES.MODE_CBC, iv)
     plaintext = cipher.decrypt(ciphertext[AES.block_size:])
     return plaintext.rstrip(b"\0")
 
+
 def encrypt_file(file_name, key):
     with open(file_name, "rb") as fo:
         plaintext = fo.read()
@@ -27,10 +32,10 @@ def encrypt_file(file_name, key):
     with open(file_name + ".enc", "wb") as fo:
         fo.write(enc)
 
+
 def decrypt_file(file_name, key):
     with open(file_name, "rb") as fo:
         ciphertext = fo.read()
     dec = decrypt(ciphertext, key)
     with open(file_name[:-4]+".test", "wb") as fo:
         fo.write(dec)
-
